==> photoupload.6.4.7.789.zip: photoupload.lrplugin/NPPTar.lua <==
LuaQ     @..\common\NPPTar.lua              
   E   @  \                 	A      	          	               	          require 
   NPPLogger 
   NPPUtilities 
   createZip    extractZip 
   resetTarFile    tarFile        '   A    M   E  A  \   D  F \   J   BA B BA B BA B BA  @  B BA B BAC @   B BA  A  B B  FC   \C     @ ^        require    NPPFile    commandLineQuotation    tarFile    table    insert 	   --create    --file 
   --format zip 
   --directory     *    concat         commandLineExecuteWithOutput     M   -   -   -   .   .   /   1   1   1   1   1   1   1   2   3   3   3   3   3   4   4   4   4   4   5   5   5   5   5   6   6   6   6   6   6   6   6   7   7   7   7   7   8   8   8   8   8   8   8   8   8   9   9   9   9   9   9   9   9   :   :   :   :   :   ;   =   =   =   =   =   =   =   =   @   @   @   A   
      taskID     L      zipFile     L      addFromFolder     L      ok     L   
   errorMessage     L      NPPFile    L   
   quotation    L      tarFilePathWithName    L      tarVersion    L   
   arguments    L      commandLine @   L      output A   L      commandLineResult A   L         NPPTar     E   ]    @   E  A  \   D  F \   J   BA B BA B BA B BA  @  B BA @   B BB  F   \C     @ ^        require    NPPFile    commandLineQuotation    tarFile    table    insert 
   --extract    --file 
   --directory     concat         commandLineExecuteWithOutput     @   K   K   K   L   L   M   O   O   O   O   O   O   O   P   Q   Q   Q   Q   Q   R   R   R   R   R   S   S   S   S   S   T   T   T   T   T   T   T   T   U   U   U   U   U   U   U   U   U   V   V   V   V   V   W   Y   Y   Y   Y   Y   Y   Y   Y   \   \   \   ]   
      taskID     ?      zipFile     ?      extractToFolder     ?      ok     ?   
   errorMessage     ?      NPPFile    ?   
   quotation    ?      tarFilePathWithName    ?      tarVersion    ?   
   arguments    ?      commandLine 3   ?      output 4   ?      commandLineResult 4   ?         NPPTar     a   f            @ @     @ A@      @           
   logOutput    INFO 
   Old value =         b   b   b   d   d   d   d   d   d   e   e   f          
   NPPLogger 	   _tarFile    _tarFileChecked     j       ^   D   Z@  @C        @ A@    A    @      @     ܀   ܁ B CB    @ B@ @    @H  B CCA  E FC \ C@  B CCA    @ H@        AD @  UA @       H  H        D     ^          WIN_ENV    tar.exe    tar    runningInLightroom    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault %   configurationExternalBinaryFilesPath 
   --version    findExternalBinaryFile    stringTrimRight    string    char       *@      $@   NPPFile    commandLineExecuteWithOutput     --version     ^   m   m   m   n   o   o   o   p   p   r   t   t   t   t   t   u   u   u   v   v   v   w   z   z   z   {   |   }   }   }   }   }   }   }   }   }   }   ~   ~                                                                                                                                                                              taskID     ]   	   fileName    Y   
   NPPPlugin    B   
   NPPConfig    B      ok    B      filePathWithName    B   
   errorMessage    B      configurationPath    B      fileCommandLineArguments    B      commandLineOutput    B      NPPFile F   W      ok G   W   
   errorMessage G   W      output G   W      commandLineResult G   W         _tarFileChecked 
   NPPUtilities 	   _tarFile    _tarVersion    _tarFileErrorMessage                               A   A   '   ]   ]   E   f   f   f   f   a                     j               NPPTar       
   NPPLogger       
   NPPUtilities          _tarFileChecked       	   _tarFile 	         _tarFileErrorMessage 	         _tarVersion 	          

==> photoupload.6.4.7.852.zip: photoupload.lrplugin/NPPTar.lua <==
LuaQ     @..\common\NPPTar.lua              
   E   @  \                 	A      	          	               	          require 
   NPPLogger 
   NPPUtilities 
   createZip    extractZip 
   resetTarFile    tarFile        '   A    M   E  A  \   D  F \   J   BA B BA B BA B BA  @  B BA B BAC @   B BA  A  B B  FC   \C     @ ^        require    NPPFile    commandLineQuotation    tarFile    table    insert 	   --create    --file 
   --format zip 
   --directory     *    concat         commandLineExecuteWithOutput     M   -   -   -   .   .   /   1   1   1   1   1   1   1   2   3   3   3   3   3   4   4   4   4   4   5   5   5   5   5   6   6   6   6   6   6   6   6   7   7   7   7   7   8   8   8   8   8   8   8   8   8   9   9   9   9   9   9   9   9   :   :   :   :   :   ;   =   =   =   =   =   =   =   =   @   @   @   A   
      taskID     L      zipFile     L      addFromFolder     L      ok     L   
   errorMessage     L      NPPFile    L   
   quotation    L      tarFilePathWithName    L      tarVersion    L   
   arguments    L      commandLine @   L      output A   L      commandLineResult A   L         NPPTar     E   ]    @   E  A  \   D  F \   J   BA B BA B BA B BA  @  B BA @   B BB  F   \C     @ ^        require    NPPFile    commandLineQuotation    tarFile    table    insert 
   --extract    --file 
   --directory     concat         commandLineExecuteWithOutput     @   K   K   K   L   L   M   O   O   O   O   O   O   O   P   Q   Q   Q   Q   Q   R   R   R   R   R   S   S   S   S   S   T   T   T   T   T   T   T   T   U   U   U   U   U   U   U   U   U   V   V   V   V   V   W   Y   Y   Y   Y   Y   Y   Y   Y   \   \   \   ]   
      taskID     ?      zipFile     ?      extractToFolder     ?      ok     ?   
   errorMessage     ?      NPPFile    ?   
   quotation    ?      tarFilePathWithName    ?      tarVersion    ?   
   arguments    ?      commandLine 3   ?      output 4   ?      commandLineResult 4   ?         NPPTar     a   f            @ @     @ A@      @           
   logOutput    INFO 
   Old value =         b   b   b   d   d   d   d   d   d   e   e   f          
   NPPLogger 	   _tarFile    _tarFileChecked     j       S   D   Z@  C        @ A@    A    @     
  @     ܀   ܁ B CB    @ B@ @    H  B @  BC @ H@       C @  UA @       H  H        D     ^          WIN_ENV    tar.exe    tar    runningInLightroom    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault %   configurationExternalBinaryFilesPath 
   --version    findExternalBinaryFile    stringTrimRight    
    
    NPPFile    commandLineExecuteWithOutput     --version     S   m   m   m   n   o   o   o   p   p   r   t   t   t   t   t   u   u   u   v   v   v   w   z   z   z   {   |   }   }   }   }   }   }   }   }   }   }   ~   ~                                                                                                                                             taskID     R   	   fileName    N   
   NPPPlugin    7   
   NPPConfig    7      ok    7      filePathWithName    7   
   errorMessage    7      configurationPath    7      fileCommandLineArguments    7      commandLineOutput    7      NPPFile ;   L      ok <   L   
   errorMessage <   L      output <   L      commandLineResult <   L         _tarFileChecked 
   NPPUtilities 	   _tarFile    _tarVersion    _tarFileErrorMessage                               A   A   '   ]   ]   E   f   f   f   f   a                     j               NPPTar       
   NPPLogger       
   NPPUtilities          _tarFileChecked       	   _tarFile 	         _tarFileErrorMessage 	         _tarVersion 	          
